use strum_macros::{AsRefStr, Display, EnumIter, EnumString};

#[derive(Debug, EnumIter, EnumString, Display, PartialEq, AsRefStr)]
pub enum MessageId {
    /// 无效请求
    BadRequest,
    /// 系统内部错误
    ServerInternalError,

    /// 问候
    Hello,
    /// 账户已禁用
    AccountDisabled,
    /// 账户无权限
    AccountNoPermission,
    /// 用户名或密码错误
    IncorrectUsernameOrPassword,
    /// 无效令牌
    InvalidToken,
    /// 无效参数
    InvalidParams,

    /// 反馈内容不能为空
    ValidateFeedbackContentRequired,
    /// 用户名称不能为空
    ValidateAccountNameRequired,
    /// 密码不能为空
    ValidateAccountPasswordRequired,
    /// 用户ID Token不能为空
    ValidateAccountIdTokenRequired,
    /// 用户语言标识不能为空
    ValidateAccountLangTagRequired,
    /// 页码无效
    ValidatePageablePageRequired,
    /// 每页数量无效
    ValidatePageablePageSizeRequired,
    /// 无效的微信code
    ValidateWxMinAppLoginCodeRequired,

    /// social begin

    /// 获取微信access_token失败
    FailedGetWxAccessToken,
    /// 微信登录失败，校验code失败
    FailedWeChatLogin,
    /// 微信用户的openid不能为空
    ValidateWxMinAppLoginInfoOpenidRequired,
    /// 微信用户的session key不能为空
    ValidateWxMinAppLoginSessionRequired,
}
