extern crate proc_macro2;
extern crate quote;
extern crate syn;
extern crate proc_macro;

use parse::{Parse, ParseStream};
use proc_macro::{Span, TokenStream};
use punctuated::Punctuated;
use quote::quote;
use syn::*;
use syn::{parse_macro_input, ItemFn};

struct WsRouteArgs {
    path: String,
}

impl Parse for WsRouteArgs {
    fn parse(input: ParseStream) -> Result<Self> {
        let args = Punctuated::<Expr, Token![,]>::parse_terminated(input)?;
        let mut path = None;

        for expr in args {
            match expr {
                Expr::Lit(ExprLit {
                    lit: Lit::Str(lit_str),
                    ..
                }) => {
                    let path_str = lit_str.value();
                    validate_route_path(&path_str)?;
                    path = Some(path_str);
                }
                _ => {}
            }
        }

        let path = path.ok_or_else(|| Error::new(
            Span::call_site().into(),
            "WebSocket路由路径参数不能为空",
        ))?;

        Ok(WsRouteArgs { path })
    }
}

fn validate_route_path(path: &str) -> Result<()> {
    if !path.starts_with('/') {
        return Err(Error::new(
            Span::call_site().into(),
            "WebSocket路由路径必须以'/'开头",
        ));
    }
    Ok(())
}

pub fn gen_ws_route(attr: TokenStream, item: TokenStream) -> TokenStream {
    let func = parse_macro_input!(item as ItemFn);
    let WsRouteArgs { path } = parse_macro_input!(attr as WsRouteArgs);
    let ident = func.sig.ident.clone();

    let generated = quote! {
        #[allow(non_camel_case_types)]
        struct #ident;
        impl #ident {
            #func
        }
        impl library::typed_router::RouteMethod for #ident {
            fn ge_router(&self, router: axum::Router) -> axum::Router {
                router.route(#path, axum::routing::any(#ident::#ident))
            }
        }
        ::library::submit_router_method!(#ident);
    };

    TokenStream::from(generated)
}
